import * as React from 'react';
import {getMimeTypeDescription, ImageFile} from '../../utils/blob';
import {formatFileSize, formatNumeral} from '../../utils/numeral';

export interface ImageFilePreviewProps {
  file: ImageFile;
}

export const ImageFilePreview: React.FC<ImageFilePreviewProps> = ({
  file: f,
}) => {
  return (
    <div className="flex gap-4 w-full h-full relative">
      <div className={`h-full w-1/3 flex-shrink-0`}>
        {
          typeof f.metadata?.previewUrl === 'string'
          && (
            <img
              className="block w-full h-full object-center object-cover"
              src={f.metadata.previewUrl}
              alt={f.name}
              data-testid="preview"
            />
          )
        }
      </div>
      <dl className="w-2/3 flex-shrink-0 m-0" data-testid="infoBox">
        <div className="w-full">
          <dt className="sr-only">
            Name
          </dt>
          <dd
            className="m-0 w-full text-ellipsis overflow-hidden"
            title={f.name}
          >
            {f.name}
          </dd>
        </div>
        <div className="w-full">
          <dt className="sr-only">
            Type
          </dt>
          <dd
            title={f.type}
            className="m-0 w-full text-ellipsis overflow-hidden"
          >
            {getMimeTypeDescription(f.type, f.name)}
          </dd>
        </div>
        <div className="w-full">
          <dt className="sr-only">
            Size
          </dt>
          <dd
            className="m-0 w-full text-ellipsis overflow-hidden"
            title={`${formatNumeral(f.size ?? 0)} bytes`}
          >
            {formatFileSize(f.size)}
          </dd>
        </div>
        {
          typeof f.metadata?.width === 'number'
          && typeof f.metadata?.height === 'number'
          && (
            <div>
              <dt className="sr-only">
                Pixel Dimensions
              </dt>
              <dd
                className="m-0 w-full text-ellipsis overflow-hidden"
              >
                {formatNumeral(f.metadata.width)}&times;{formatNumeral(f.metadata.height)} pixels
              </dd>
            </div>
          )
        }
      </dl>
    </div>
  );
}
